# ickafka

A kafka consumer with color.

![ickafka_demo](https://user-images.githubusercontent.com/4519234/44621701-d6516300-a878-11e8-8ab7-752e7b286352.gif)

## Installation

```bash
pip install ickafka
```

## Usage

```bash
ickafka [-h] [-s SERVER] [-g GROUP] [-o OFFSET] -t TOPIC
```
